==> qt5-base-debuginfo-5.9.3-2.tar.xz: usr/src/debug/qt5-base-5.9.3-2/examples/network/securesocketclient/.rcc/qrc_securesocketclient.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.9.3-2.x86_64/src/qtbase-opensource-src-5.9.3/examples/network/securesocketclient/encrypted.png
  0x0,0x0,0x2,0xee,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x12,0x0,0x0,
  0xb,0x12,0x1,0xd2,0xdd,0x7e,0xfc,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,
  0xd3,0xa,0xa,0x16,0x13,0x24,0x38,0x34,0x46,0x65,0x0,0x0,0x2,0x7b,0x49,0x44,
  0x41,0x54,0x78,0xda,0x7d,0x92,0x4d,0x48,0x54,0x51,0x14,0xc7,0x7f,0xce,0xf7,0xe8,
  0xe8,0x38,0xf8,0x31,0xa9,0xc9,0x4,0x49,0x82,0x52,0x8,0x2a,0x43,0x90,0x50,0x90,
  0xb5,0x77,0x29,0x44,0xeb,0x5a,0xb8,0x6a,0x8,0x84,0x70,0x13,0xb6,0x99,0x9d,0x6e,
  0x82,0x20,0x28,0xc2,0x45,0xab,0x5c,0x58,0xd0,0xca,0x8d,0xd6,0x22,0x34,0xf0,0x3b,
  0x94,0x21,0x4d,0x67,0x86,0x71,0xde,0x38,0xcf,0xf7,0xee,0xbc,0xef,0x16,0xd3,0x8c,
  0x53,0x92,0x67,0x75,0xee,0x3d,0xff,0xff,0xef,0x5c,0xce,0xb9,0x75,0xfc,0x13,0xd3,
  0xd3,0x6f,0x23,0x6d,0x6d,0xe1,0x87,0xad,0xad,0xcd,0x8f,0x9a,0x9a,0xea,0xaf,0x1,
  0xc8,0xb2,0x9a,0xca,0x66,0xa5,0x99,0x5c,0xae,0xf8,0x7a,0x72,0xf2,0x81,0x54,0xab,
  0x77,0xd7,0x1e,0xa6,0xa6,0x5e,0xb5,0x84,0xc3,0xa1,0x44,0x3c,0xde,0xff,0x6c,0x68,
  0xa8,0x37,0x1a,0x8b,0xb5,0xd3,0xd5,0xd5,0x42,0x77,0x77,0x7b,0x73,0x20,0xe0,0xbb,
  0x9d,0x4e,0xe7,0xdd,0xf1,0xf8,0xfd,0xd5,0xc5,0xc5,0x79,0x71,0xe,0x90,0x48,0xcc,
  0xb8,0xea,0xeb,0x3,0x63,0x23,0x23,0x37,0xa6,0x7a,0x7b,0xbb,0x1b,0x76,0x77,0xf7,
  0x8d,0xe5,0xe5,0xb5,0xc2,0xd6,0x56,0x4a,0x55,0x55,0xc5,0xdd,0xd3,0x73,0xd9,0xef,
  0xf3,0x79,0xae,0xa7,0x52,0xe9,0x1f,0xc3,0xc3,0xa3,0x6b,0x4b,0x4b,0x1f,0x1d,0x0,
  0x4f,0x5,0xa0,0xeb,0x46,0x43,0x34,0x1a,0x19,0x8f,0xc5,0xa2,0xe1,0xcd,0xcd,0x3d,
  0x6d,0x61,0xe1,0xcb,0x1b,0x55,0xd5,0x9e,0x3,0xca,0xca,0x4a,0xdd,0x53,0x49,0x2a,
  0x3c,0x1e,0x18,0xe8,0xb,0x47,0xa3,0xcd,0xe3,0xf9,0xfc,0xc9,0x7,0x40,0x6,0x70,
  0x55,0x0,0x42,0x68,0x1e,0xbf,0xdf,0x77,0xc5,0xef,0x77,0xb3,0xbe,0xbe,0x97,0xc9,
  0x64,0xa4,0x97,0xc9,0xe4,0xc4,0xcf,0x64,0x72,0xe2,0x58,0x88,0x52,0x72,0x7b,0xfb,
  0xe0,0x40,0xd7,0x5,0x3e,0x9f,0xe7,0x8a,0x10,0x5a,0xb5,0x71,0x15,0xa0,0x28,0x2a,
  0x86,0xa1,0x23,0x84,0x20,0x93,0xc9,0x9f,0x98,0xa6,0xb9,0x5a,0xa9,0xcd,0xce,0x26,
  0xb2,0xb2,0xac,0x68,0x9a,0x56,0x42,0xd7,0x75,0x14,0x45,0xad,0xce,0xad,0x4a,0xba,
  0x79,0x69,0x33,0x84,0xe8,0xf4,0xa,0x69,0x1f,0xaf,0x99,0xf5,0x4c,0xe,0xce,0x75,
  0x4e,0xe,0xf6,0x57,0x85,0x73,0xbf,0x24,0xaf,0x75,0x9a,0xc6,0x55,0xca,0x78,0xef,
  0x76,0x7f,0x8f,0xbc,0x3,0x9,0xa0,0xe,0x60,0x35,0xd9,0x37,0xea,0xd,0xd6,0x27,
  0xac,0xc8,0xd5,0x91,0x50,0x63,0x28,0x70,0x22,0x15,0x44,0x24,0x20,0xaf,0xd7,0x6e,
  0xe8,0x58,0x84,0xfa,0x9b,0x9a,0xc3,0x41,0xf5,0x54,0x29,0x79,0xa,0x7b,0xcb,0x86,
  0x50,0x5f,0xc,0x3c,0xd9,0xf8,0xec,0x1,0xc8,0x4a,0xdc,0x8b,0x8f,0xdd,0x1a,0x6d,
  0xea,0xc8,0x1,0xc7,0x80,0x13,0x84,0xe0,0x50,0x2d,0x20,0x86,0x5,0xe4,0xc1,0x71,
  0x2,0xc5,0x9d,0x8e,0x3b,0x5f,0xdf,0xef,0x7e,0x3,0xca,0x80,0xa3,0x9c,0x8d,0xa5,
  0xee,0x40,0x31,0xc7,0x85,0xe1,0x0,0x92,0xc0,0xda,0x90,0x38,0xca,0x85,0xce,0x66,
  0x70,0x98,0x73,0x30,0xa,0x2a,0xf8,0xb4,0xb,0xcc,0xe,0x14,0x4b,0x70,0x70,0x82,
  0x21,0x39,0x1c,0xe6,0x9c,0x33,0x40,0xbe,0xe8,0x60,0x15,0x35,0xf0,0x8a,0xbf,0xd,
  0x95,0xae,0x96,0xd,0x8a,0xe,0xc7,0x2a,0x18,0x16,0x56,0xc9,0x45,0xbe,0x58,0x3,
  0x70,0x1c,0x40,0x35,0xc0,0xaf,0x81,0xab,0xe,0x6c,0x7,0x4c,0xbb,0x6c,0x34,0x6d,
  0xd0,0x2d,0x28,0x19,0x60,0xd8,0x60,0x58,0xa0,0xbb,0xab,0xfc,0xea,0x1a,0x31,0xec,
  0x32,0x49,0xff,0x23,0x32,0x6c,0x30,0xad,0xb2,0xd9,0xb4,0xcf,0xcc,0xa6,0x5,0x3a,
  0xe7,0xff,0x81,0x70,0x82,0x67,0xa2,0x2a,0xa0,0x6,0x56,0xb9,0x37,0x6d,0x84,0x70,
  0x9f,0x3,0xec,0xcc,0x7f,0x92,0xe5,0x6,0xaf,0xbf,0x11,0xdb,0x29,0xbf,0xc4,0x81,
  0xff,0xe5,0x8a,0xee,0x92,0x81,0x1d,0x80,0xdf,0xdd,0xb9,0x5b,0xe8,0xaf,0xff,0x94,
  0x7,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // encrypted.png
  0x0,0xd,
  0x2,0x22,0x16,0x7,
  0x0,0x65,
  0x0,0x6e,0x0,0x63,0x0,0x72,0x0,0x79,0x0,0x70,0x0,0x74,0x0,0x65,0x0,0x64,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/encrypted.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0xc3,0x40,0xd9,0x80,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_securesocketclient)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_securesocketclient)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_securesocketclient)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_securesocketclient)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_securesocketclient)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_securesocketclient)(); }
   } dummy;
}

==> qt5-base-debuginfo-5.9.4-1.tar.xz: usr/src/debug/qt5-base-5.9.4-1/examples/network/securesocketclient/.rcc/qrc_securesocketclient.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.4
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-base/qt5-base-5.9.4-1.i686/src/qtbase-opensource-src-5.9.4/examples/network/securesocketclient/encrypted.png
  0x0,0x0,0x2,0xee,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0xb,0x12,0x0,0x0,
  0xb,0x12,0x1,0xd2,0xdd,0x7e,0xfc,0x0,0x0,0x0,0x7,0x74,0x49,0x4d,0x45,0x7,
  0xd3,0xa,0xa,0x16,0x13,0x24,0x38,0x34,0x46,0x65,0x0,0x0,0x2,0x7b,0x49,0x44,
  0x41,0x54,0x78,0xda,0x7d,0x92,0x4d,0x48,0x54,0x51,0x14,0xc7,0x7f,0xce,0xf7,0xe8,
  0xe8,0x38,0xf8,0x31,0xa9,0xc9,0x4,0x49,0x82,0x52,0x8,0x2a,0x43,0x90,0x50,0x90,
  0xb5,0x77,0x29,0x44,0xeb,0x5a,0xb8,0x6a,0x8,0x84,0x70,0x13,0xb6,0x99,0x9d,0x6e,
  0x82,0x20,0x28,0xc2,0x45,0xab,0x5c,0x58,0xd0,0xca,0x8d,0xd6,0x22,0x34,0xf0,0x3b,
  0x94,0x21,0x4d,0x67,0x86,0x71,0xde,0x38,0xcf,0xf7,0xee,0xbc,0xef,0x16,0xd3,0x8c,
  0x53,0x92,0x67,0x75,0xee,0x3d,0xff,0xff,0xef,0x5c,0xce,0xb9,0x75,0xfc,0x13,0xd3,
  0xd3,0x6f,0x23,0x6d,0x6d,0xe1,0x87,0xad,0xad,0xcd,0x8f,0x9a,0x9a,0xea,0xaf,0x1,
  0xc8,0xb2,0x9a,0xca,0x66,0xa5,0x99,0x5c,0xae,0xf8,0x7a,0x72,0xf2,0x81,0x54,0xab,
  0x77,0xd7,0x1e,0xa6,0xa6,0x5e,0xb5,0x84,0xc3,0xa1,0x44,0x3c,0xde,0xff,0x6c,0x68,
  0xa8,0x37,0x1a,0x8b,0xb5,0xd3,0xd5,0xd5,0x42,0x77,0x77,0x7b,0x73,0x20,0xe0,0xbb,
  0x9d,0x4e,0xe7,0xdd,0xf1,0xf8,0xfd,0xd5,0xc5,0xc5,0x79,0x71,0xe,0x90,0x48,0xcc,
  0xb8,0xea,0xeb,0x3,0x63,0x23,0x23,0x37,0xa6,0x7a,0x7b,0xbb,0x1b,0x76,0x77,0xf7,
  0x8d,0xe5,0xe5,0xb5,0xc2,0xd6,0x56,0x4a,0x55,0x55,0xc5,0xdd,0xd3,0x73,0xd9,0xef,
  0xf3,0x79,0xae,0xa7,0x52,0xe9,0x1f,0xc3,0xc3,0xa3,0x6b,0x4b,0x4b,0x1f,0x1d,0x0,
  0x4f,0x5,0xa0,0xeb,0x46,0x43,0x34,0x1a,0x19,0x8f,0xc5,0xa2,0xe1,0xcd,0xcd,0x3d,
  0x6d,0x61,0xe1,0xcb,0x1b,0x55,0xd5,0x9e,0x3,0xca,0xca,0x4a,0xdd,0x53,0x49,0x2a,
  0x3c,0x1e,0x18,0xe8,0xb,0x47,0xa3,0xcd,0xe3,0xf9,0xfc,0xc9,0x7,0x40,0x6,0x70,
  0x55,0x0,0x42,0x68,0x1e,0xbf,0xdf,0x77,0xc5,0xef,0x77,0xb3,0xbe,0xbe,0x97,0xc9,
  0x64,0xa4,0x97,0xc9,0xe4,0xc4,0xcf,0x64,0x72,0xe2,0x58,0x88,0x52,0x72,0x7b,0xfb,
  0xe0,0x40,0xd7,0x5,0x3e,0x9f,0xe7,0x8a,0x10,0x5a,0xb5,0x71,0x15,0xa0,0x28,0x2a,
  0x86,0xa1,0x23,0x84,0x20,0x93,0xc9,0x9f,0x98,0xa6,0xb9,0x5a,0xa9,0xcd,0xce,0x26,
  0xb2,0xb2,0xac,0x68,0x9a,0x56,0x42,0xd7,0x75,0x14,0x45,0xad,0xce,0xad,0x4a,0xba,
  0x79,0x69,0x33,0x84,0xe8,0xf4,0xa,0x69,0x1f,0xaf,0x99,0xf5,0x4c,0xe,0xce,0x75,
  0x4e,0xe,0xf6,0x57,0x85,0x73,0xbf,0x24,0xaf,0x75,0x9a,0xc6,0x55,0xca,0x78,0xef,
  0x76,0x7f,0x8f,0xbc,0x3,0x9,0xa0,0xe,0x60,0x35,0xd9,0x37,0xea,0xd,0xd6,0x27,
  0xac,0xc8,0xd5,0x91,0x50,0x63,0x28,0x70,0x22,0x15,0x44,0x24,0x20,0xaf,0xd7,0x6e,
  0xe8,0x58,0x84,0xfa,0x9b,0x9a,0xc3,0x41,0xf5,0x54,0x29,0x79,0xa,0x7b,0xcb,0x86,
  0x50,0x5f,0xc,0x3c,0xd9,0xf8,0xec,0x1,0xc8,0x4a,0xdc,0x8b,0x8f,0xdd,0x1a,0x6d,
  0xea,0xc8,0x1,0xc7,0x80,0x13,0x84,0xe0,0x50,0x2d,0x20,0x86,0x5,0xe4,0xc1,0x71,
  0x2,0xc5,0x9d,0x8e,0x3b,0x5f,0xdf,0xef,0x7e,0x3,0xca,0x80,0xa3,0x9c,0x8d,0xa5,
  0xee,0x40,0x31,0xc7,0x85,0xe1,0x0,0x92,0xc0,0xda,0x90,0x38,0xca,0x85,0xce,0x66,
  0x70,0x98,0x73,0x30,0xa,0x2a,0xf8,0xb4,0xb,0xcc,0xe,0x14,0x4b,0x70,0x70,0x82,
  0x21,0x39,0x1c,0xe6,0x9c,0x33,0x40,0xbe,0xe8,0x60,0x15,0x35,0xf0,0x8a,0xbf,0xd,
  0x95,0xae,0x96,0xd,0x8a,0xe,0xc7,0x2a,0x18,0x16,0x56,0xc9,0x45,0xbe,0x58,0x3,
  0x70,0x1c,0x40,0x35,0xc0,0xaf,0x81,0xab,0xe,0x6c,0x7,0x4c,0xbb,0x6c,0x34,0x6d,
  0xd0,0x2d,0x28,0x19,0x60,0xd8,0x60,0x58,0xa0,0xbb,0xab,0xfc,0xea,0x1a,0x31,0xec,
  0x32,0x49,0xff,0x23,0x32,0x6c,0x30,0xad,0xb2,0xd9,0xb4,0xcf,0xcc,0xa6,0x5,0x3a,
  0xe7,0xff,0x81,0x70,0x82,0x67,0xa2,0x2a,0xa0,0x6,0x56,0xb9,0x37,0x6d,0x84,0x70,
  0x9f,0x3,0xec,0xcc,0x7f,0x92,0xe5,0x6,0xaf,0xbf,0x11,0xdb,0x29,0xbf,0xc4,0x81,
  0xff,0xe5,0x8a,0xee,0x92,0x81,0x1d,0x80,0xdf,0xdd,0xb9,0x5b,0xe8,0xaf,0xff,0x94,
  0x7,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // encrypted.png
  0x0,0xd,
  0x2,0x22,0x16,0x7,
  0x0,0x65,
  0x0,0x6e,0x0,0x63,0x0,0x72,0x0,0x79,0x0,0x70,0x0,0x74,0x0,0x65,0x0,0x64,0x0,0x2e,0x0,0x70,0x0,0x6e,0x0,0x67,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/encrypted.png
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x60,0xfd,0xbe,0xb8,0xd8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_securesocketclient)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_securesocketclient)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_securesocketclient)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_securesocketclient)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_securesocketclient)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_securesocketclient)(); }
   } dummy;
}
